BarLabelDecorator<D> class

Constructors

BarLabelDecorator({TextStyleSpec? insideLabelStyleSpec, TextStyleSpec? outsideLabelStyleSpec, BarLabelAnchor? labelAnchor, BarLabelPosition labelPosition = _defaultLabelPosition, BarLabelPlacement labelPlacement = _defaultLabelPlacement, int labelPadding = _defaultLabelPadding, BarLabelVerticalPosition? labelVerticalPosition = _defaultlabelVerticalPosition})

Properties

hashCode → int
The hash code for this object.
no setterinherited
insideLabelStyleSpec → TextStyleSpec
Configures TextStyleSpec for labels placed inside the bars.
final
labelAnchor → BarLabelAnchor?
For labels drawn inside the bar, configures label anchor position.
final
labelPadding → int
Space before and after the label text.
final
labelPlacement → BarLabelPlacement
Configures where to place the label relative to the axis.
final
labelPosition → BarLabelPosition
Configures where to place the label relative to the bars.
final
labelVerticalPosition → BarLabelVerticalPosition?
For labels on horizontal bars, configures the label's vertical position.
final
outsideLabelStyleSpec → TextStyleSpec
Configures TextStyleSpec for labels placed outside the bars.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

decorate(Iterable<ImmutableBarRendererElement<D>> barElements, ChartCanvas canvas, GraphicsFactory graphicsFactory, {required Rectangle<int> drawBounds, required double animationPercent, required bool renderingVertically, bool rtl = false}) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited