OrdinalComboChart class

An ordinal combo chart supports rendering each series of data with different series renderers.

Inheritance

Constructors

OrdinalComboChart(List<Series<dynamic, String>> seriesList, {bool? animate, Duration? animationDuration, AxisSpec? domainAxis, NumericAxisSpec? primaryMeasureAxis, NumericAxisSpec? secondaryMeasureAxis, SeriesRendererConfig<String>? defaultRenderer, List<SeriesRendererConfig<String>>? customSeriesRenderers, List<ChartBehavior<String>>? behaviors, List<SelectionModelConfig<String>>? selectionModels, RTLSpec? rtlSpec, LayoutConfig? layoutConfig, bool defaultInteractions = true})

Properties

animate → bool
Animation transitions.
finalinherited
animationDuration → Duration
finalinherited
behaviors → List<ChartBehavior<String>>?
finalinherited
customSeriesRenderers → List<SeriesRendererConfig<String>>?
finalinherited
defaultInteractions → bool
Include the default interactions or not.
finalinherited
defaultRenderer → SeriesRendererConfig<String>?
finalinherited
disjointMeasureAxes → LinkedHashMap<String, NumericAxisSpec>?
finalinherited
domainAxis → AxisSpec?
finalinherited
flipVerticalAxis → bool?
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
layoutConfig → LayoutConfig?
Used to configure the margin sizes around the drawArea that the axis and other things render into.
finalinherited
primaryMeasureAxis → NumericAxisSpec?
finalinherited
rtlSpec → RTLSpec?
The spec to use if RTL is enabled.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secondaryMeasureAxis → NumericAxisSpec?
finalinherited
selectionModels → List<SelectionModelConfig<String>>?
finalinherited
seriesList → List<Series<dynamic, String>>
Series list to draw.
finalinherited
userManagedState → UserManagedState<String>?
Optional state that overrides internally kept state, such as selection.
finalinherited

Methods

addDefaultInteractions(List<ChartBehavior> behaviors) → void
Create the list of default interaction behaviors.
inherited
createCommonChart(BaseChartState chartState) → OrdinalCartesianChart
Creates and returns a common.BaseChart.
override
createDisjointMeasureAxes() → LinkedHashMap<String, NumericAxis>?
inherited
createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → BaseChartState<String>
Creates the mutable state for this widget at a given location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
getDesiredGestures(BaseChartState chartState) → Set<GestureType>
Gets distinct set of gestures this chart will subscribe to.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited
updateCommonChart(BaseChart<String> baseChart, BaseChart<String>? oldWidget, BaseChartState<String> chartState) → void
Updates the common.BaseChart.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited