OrdinalViewport class

Viewport to cover dataSize data points starting at startingDomain value.

Constructors

OrdinalViewport(String startingDomain, int dataSize)

Properties

dataSize → int
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startingDomain → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override