PointRendererDecorator<D> class abstract

Decorates points after the points have already been painted.

Constructors

PointRendererDecorator()
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
renderAbove → bool
Configures whether the decorator should be rendered on top of or below series data elements.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

decorate(PointRendererElement<D> pointElement, ChartCanvas canvas, GraphicsFactory graphicsFactory, {required Rectangle<num> drawBounds, required double animationPercent, bool rtl = false}) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited