SeriesDatum<D> class

Stores datum and the series the datum originated.

Constructors

SeriesDatum(ImmutableSeries<D> series, dynamic datum)

Properties

datum → dynamic
final
hashCode → int
The hash code for this object.
no setteroverride
index → int?
Returns null if-and-only if datum is null.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
series → ImmutableSeries<D>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override